@@ -1,22 +1,28 @@
 import os
 import unittest
+
 try:
     from StringIO import StringIO
 except ImportError:
     from io import StringIO
+
 import numpy as np
-from spglib import (get_ir_reciprocal_mesh,
-                    get_stabilized_reciprocal_mesh,
-                    get_symmetry_dataset,
-                    relocate_BZ_grid_address,
-                    get_grid_points_by_rotations,
-                    get_BZ_grid_points_by_rotations,
-                    get_grid_point_from_address)
 from vasp import read_vasp
 
+from spglib import (
+    get_BZ_grid_points_by_rotations,
+    get_grid_point_from_address,
+    get_grid_points_by_rotations,
+    get_ir_reciprocal_mesh,
+    get_stabilized_reciprocal_mesh,
+    get_symmetry_dataset,
+    relocate_BZ_grid_address,
+)
+
 data_dir = os.path.dirname(os.path.abspath(__file__))
 
-result_ir_rec_mesh = ("""   0    0   0   0
+result_ir_rec_mesh = (
+    """   0    0   0   0
    1    1   0   0
    2    2   0   0
    1   -1   0   0
@@ -79,7 +85,8 @@ result_ir_rec_mesh = ("""   0    0   0   0
    5    0  -1  -1
   21    1  -1  -1
   22    2  -1  -1
-  21   -1  -1  -1""", """   0    0   0   0
+  21   -1  -1  -1""",
+    """   0    0   0   0
    1    1   0   0
    2    2   0   0
    1   -1   0   0
@@ -110,7 +117,8 @@ result_ir_rec_mesh = ("""   0    0   0   0
   17    0  -1   1
   17    1  -1   1
   21    2  -1   1
-  21   -1  -1   1""", """   0    0   0   0
+  21   -1  -1   1""",
+    """   0    0   0   0
    1    1   0   0
    1   -1   0   0
    1    0   1   0
@@ -136,9 +144,11 @@ result_ir_rec_mesh = ("""   0    0   0   0
    5   -1   1  -1
    4    0  -1  -1
    5    1  -1  -1
-   1   -1  -1  -1""")
+   1   -1  -1  -1""",
+)
 
-result_ir_rec_mesh_distortion = ("""  0    0   0   0
+result_ir_rec_mesh_distortion = (
+    """  0    0   0   0
    1    1   0   0
    1   -1   0   0
    3    0   1   0
@@ -185,7 +195,8 @@ result_ir_rec_mesh_distortion = ("""  0    0   0   0
   19   -1   2  -1
   15    0  -1  -1
   16    1  -1  -1
-  16   -1  -1  -1""", """   0    0   0   0
+  16   -1  -1  -1""",
+    """   0    0   0   0
    1    1   0   0
    1   -1   0   0
    3    0   1   0
@@ -199,7 +210,8 @@ result_ir_rec_mesh_distortion = ("""  0    0   0   0
    7   -1  -2   0
    3    0  -1   0
    5    1  -1   0
-   4   -1  -1   0""", """   0    0   0   0
+   4   -1  -1   0""",
+    """   0    0   0   0
    1    1   0   0
    1   -1   0   0
    3    0   1   0
@@ -246,7 +258,8 @@ result_ir_rec_mesh_distortion = ("""  0    0   0   0
   16   -1   2  -1
   12    0  -1  -1
   13    1  -1  -1
-  13   -1  -1  -1""", """   0    0   0   0
+  13   -1  -1  -1""",
+    """   0    0   0   0
    1    1   0   0
    2   -1   0   0
    3    0   1   0
@@ -260,7 +273,8 @@ result_ir_rec_mesh_distortion = ("""  0    0   0   0
    4   -1  -2   0
    0    0  -1   0
    2    1  -1   0
-   1   -1  -1   0""")
+   1   -1  -1   0""",
+)
 
 result_ir_rec_mesh_silicon = """    0    0   0   0
    1    1   0   0
@@ -290,7 +304,8 @@ result_ir_rec_mesh_silicon = """    0    0   0   0
    1    1  -1  -1
    0   -1  -1  -1"""
 
-result_bz_grid_address = ("""  0  0  0
+result_bz_grid_address = (
+    """  0  0  0
  1  0  0
  2  0  0
 -1  0  0
@@ -414,7 +429,8 @@ result_bz_grid_address = ("""  0  0  0
 -2  2 -1
 -2 -2 -1
 -1 -2 -1
--2 -1 -1""", """ 0  0  0
+-2 -1 -1""",
+    """ 0  0  0
  1  0  0
  2  0  0
 -1  0  0
@@ -470,7 +486,8 @@ result_bz_grid_address = ("""  0  0  0
  0 -1 -1
  1 -1 -1
  2 -1 -1
--1 -1 -1""", """  0   0   0
+-1 -1 -1""",
+    """  0   0   0
   1   0   0
  -1   0   0
   0   1   0
@@ -496,9 +513,11 @@ result_bz_grid_address = ("""  0  0  0
  -1  -2  -1
   0  -1  -1
  -2  -1  -1
- -1  -1  -1""")
+ -1  -1  -1""",
+)
 
-result_bz_map = ("""  0   1   2  -1  -1  -1  64   3   4   5
+result_bz_map = (
+    """  0   1   2  -1  -1  -1  64   3   4   5
   6  -1  -1  -1  65   7   8   9  10  -1
  -1  -1  69  11  -1  -1  -1  -1  -1  -1
  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1
@@ -549,7 +568,8 @@ result_bz_map = ("""  0   1   2  -1  -1  -1  64   3   4   5
  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1
  -1  -1  -1  -1  -1  -1 118 119 120  -1
  -1  -1 122 123  60  61  62  -1  -1  -1
-124  63""", """  0   1   2  -1  -1  -1  32   3   4   5
+124  63""",
+    """  0   1   2  -1  -1  -1  32   3   4   5
  -1  -1  -1  -1   6   7   8  -1  -1  -1
  -1  -1  34  11  -1  -1  -1  -1  -1  -1
  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1
@@ -574,7 +594,8 @@ result_bz_map = ("""  0   1   2  -1  -1  -1  64   3   4   5
  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1
  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1
  47  48  49  -1  -1  -1  -1  -1  53  54
- 55  -1  -1  -1  -1  56""" , """  0   1  -1  -1  -1   2   3   4  -1  -1
+ 55  -1  -1  -1  -1  56""",
+    """  0   1  -1  -1  -1   2   3   4  -1  -1
  -1   5  -1  -1  -1  -1  -1  -1  -1  -1
  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1
   6   7  -1  -1  -1   8   9  10  -1  -1
@@ -595,17 +616,18 @@ result_bz_map = ("""  0   1   2  -1  -1  -1  64   3   4   5
  18  19  -1  -1  -1  20  21  -1  -1  -1
  -1  -1  -1  -1  -1  -1  -1  -1  -1  -1
  -1  -1  -1  -1  -1  -1  -1  -1  -1  23
- 24  -1  -1  -1  25  26""")
+ 24  -1  -1  -1  25  26""",
+)
 
 
 class TestReciprocalMesh(unittest.TestCase):
     def setUp(self):
-        identity = np.eye(3, dtype='intc')
+        identity = np.eye(3, dtype="intc")
         file_and_mesh = (
             [os.path.join(data_dir, "data", "cubic", "POSCAR-217"), [4, 4, 4]],
-            [os.path.join(data_dir, "data", "hexagonal", "POSCAR-182"),
-             [4, 4, 2]],
-            [os.path.join(data_dir, "POSCAR_Si_prim"), [3, 3, 3]])
+            [os.path.join(data_dir, "data", "hexagonal", "POSCAR-182"), [4, 4, 2]],
+            [os.path.join(data_dir, "POSCAR_Si_prim"), [3, 3, 3]],
+        )
 
         self.meshes = []
         self.cells = []
@@ -614,9 +636,13 @@ class TestReciprocalMesh(unittest.TestCase):
         for i, (fname, mesh) in enumerate(file_and_mesh):
             self.meshes.append(mesh)
             self.cells.append(read_vasp(fname))
-            self.rotations.append(
-                get_symmetry_dataset(self.cells[i])['rotations'])
-            _, ga = get_stabilized_reciprocal_mesh(mesh, [identity, ])
+            self.rotations.append(get_symmetry_dataset(self.cells[i])["rotations"])
+            _, ga = get_stabilized_reciprocal_mesh(
+                mesh,
+                [
+                    identity,
+                ],
+            )
             self.grid_addresses.append(ga)
 
     def tearDown(self):
@@ -624,18 +650,20 @@ class TestReciprocalMesh(unittest.TestCase):
 
     def test_get_ir_reciprocal_mesh(self):
         for i in range(len(self.cells)):
-            ir_rec_mesh = get_ir_reciprocal_mesh(self.meshes[i], self.cells[i],
-                                                 is_dense=False)
+            ir_rec_mesh = get_ir_reciprocal_mesh(
+                self.meshes[i], self.cells[i], is_dense=False
+            )
             (mapping_table, grid_address) = ir_rec_mesh
             # for gp, ga in zip(mapping_table, grid_address):
             #     print("%4d  %3d %3d %3d" % (gp, ga[0], ga[1], ga[2]))
             # print("")
-            data = np.loadtxt(StringIO(result_ir_rec_mesh[i]), dtype='intc')
+            data = np.loadtxt(StringIO(result_ir_rec_mesh[i]), dtype="intc")
             np.testing.assert_equal(data[:, 0], mapping_table)
             np.testing.assert_equal(data[:, 1:4], grid_address)
 
-            ir_rec_mesh = get_ir_reciprocal_mesh(self.meshes[i], self.cells[i],
-                                                 is_dense=True)
+            ir_rec_mesh = get_ir_reciprocal_mesh(
+                self.meshes[i], self.cells[i], is_dense=True
+            )
             (mapping_table, grid_address) = ir_rec_mesh
             np.testing.assert_equal(data[:, 0], mapping_table)
             np.testing.assert_equal(data[:, 1:4], grid_address)
@@ -644,21 +672,22 @@ class TestReciprocalMesh(unittest.TestCase):
         j = 0
         for is_shift in ([0, 0, 0], [0, 1, 0]):
             for i, mesh in enumerate(([3, 4, 4], [3, 5, 1])):
-                ir_rec_mesh = get_ir_reciprocal_mesh(mesh, self.cells[i],
-                                                     is_shift=is_shift,
-                                                     is_dense=False)
+                ir_rec_mesh = get_ir_reciprocal_mesh(
+                    mesh, self.cells[i], is_shift=is_shift, is_dense=False
+                )
                 (mapping_table, grid_address) = ir_rec_mesh
                 # for gp, ga in zip(mapping_table, grid_address):
                 #     print("%4d  %3d %3d %3d" % (gp, ga[0], ga[1], ga[2]))
                 # print("")
-                data = np.loadtxt(StringIO(result_ir_rec_mesh_distortion[j]),
-                                  dtype='intc')
+                data = np.loadtxt(
+                    StringIO(result_ir_rec_mesh_distortion[j]), dtype="intc"
+                )
                 np.testing.assert_equal(data[:, 0], mapping_table)
                 np.testing.assert_equal(data[:, 1:4], grid_address)
 
-                ir_rec_mesh = get_ir_reciprocal_mesh(mesh, self.cells[i],
-                                                     is_shift=is_shift,
-                                                     is_dense=True)
+                ir_rec_mesh = get_ir_reciprocal_mesh(
+                    mesh, self.cells[i], is_shift=is_shift, is_dense=True
+                )
                 (mapping_table, grid_address) = ir_rec_mesh
                 np.testing.assert_equal(data[:, 0], mapping_table)
                 np.testing.assert_equal(data[:, 1:4], grid_address)
@@ -666,20 +695,20 @@ class TestReciprocalMesh(unittest.TestCase):
                 j += 1
 
     def test_get_ir_reciprocal_mesh_Si_shift_111(self):
-        ir_rec_mesh = get_ir_reciprocal_mesh([3, 3, 3], self.cells[2],
-                                             is_shift=[1, 1, 1],
-                                             is_dense=False)
+        ir_rec_mesh = get_ir_reciprocal_mesh(
+            [3, 3, 3], self.cells[2], is_shift=[1, 1, 1], is_dense=False
+        )
         (mapping_table, grid_address) = ir_rec_mesh
         # for gp, ga in zip(mapping_table, grid_address):
         #     print("%4d  %3d %3d %3d" % (gp, ga[0], ga[1], ga[2]))
         # print("")
-        data = np.loadtxt(StringIO(result_ir_rec_mesh_silicon), dtype='intc')
+        data = np.loadtxt(StringIO(result_ir_rec_mesh_silicon), dtype="intc")
         np.testing.assert_equal(data[:, 0], mapping_table)
         np.testing.assert_equal(data[:, 1:4], grid_address)
 
-        ir_rec_mesh = get_ir_reciprocal_mesh([3, 3, 3], self.cells[2],
-                                             is_shift=[1, 1, 1],
-                                             is_dense=True)
+        ir_rec_mesh = get_ir_reciprocal_mesh(
+            [3, 3, 3], self.cells[2], is_shift=[1, 1, 1], is_dense=True
+        )
         (mapping_table, grid_address) = ir_rec_mesh
         np.testing.assert_equal(data[:, 0], mapping_table)
         np.testing.assert_equal(data[:, 1:4], grid_address)
@@ -687,27 +716,28 @@ class TestReciprocalMesh(unittest.TestCase):
     def test_get_stabilized_reciprocal_mesh(self):
         for i in range(len(self.cells)):
             ir_rec_mesh = get_stabilized_reciprocal_mesh(
-                self.meshes[i], self.rotations[i], is_dense=False)
+                self.meshes[i], self.rotations[i], is_dense=False
+            )
             (mapping_table, grid_address) = ir_rec_mesh
-            data = np.loadtxt(StringIO(result_ir_rec_mesh[i]), dtype='intc')
+            data = np.loadtxt(StringIO(result_ir_rec_mesh[i]), dtype="intc")
             np.testing.assert_equal(data[:, 0], mapping_table)
             np.testing.assert_equal(data[:, 1:4], grid_address)
 
             ir_rec_mesh = get_stabilized_reciprocal_mesh(
-                self.meshes[i], self.rotations[i], is_dense=True)
+                self.meshes[i], self.rotations[i], is_dense=True
+            )
             (mapping_table, grid_address) = ir_rec_mesh
             np.testing.assert_equal(data[:, 0], mapping_table)
             np.testing.assert_equal(data[:, 1:4], grid_address)
 
     def test_relocate_BZ_grid_address(self):
         for i, (cell, mesh, grid_address) in enumerate(
-                zip(self.cells, self.meshes, self.grid_addresses)):
+            zip(self.cells, self.meshes, self.grid_addresses)
+        ):
             reclat = np.linalg.inv(cell[0])
             bz_grid_address, bz_map = relocate_BZ_grid_address(
-                grid_address,
-                mesh,
-                reclat,
-                is_dense=False)
+                grid_address, mesh, reclat, is_dense=False
+            )
 
             # print(i)
             # for j in range(len(bz_map) // 10):
@@ -720,8 +750,7 @@ class TestReciprocalMesh(unittest.TestCase):
             #     print("%3d %3d %3d" % tuple(adrs))
             # print("")
 
-            data_adrs = np.loadtxt(StringIO(result_bz_grid_address[i]),
-                                   dtype='intc')
+            data_adrs = np.loadtxt(StringIO(result_bz_grid_address[i]), dtype="intc")
             np.testing.assert_equal(data_adrs, bz_grid_address)
 
             data_map = np.array([int(i) for i in result_bz_map[i].split()])
@@ -729,14 +758,13 @@ class TestReciprocalMesh(unittest.TestCase):
             np.testing.assert_equal(data_map, bz_map)
 
             bz_grid_address, bz_map = relocate_BZ_grid_address(
-                grid_address,
-                mesh,
-                reclat,
-                is_dense=True)
+                grid_address, mesh, reclat, is_dense=True
+            )
             np.testing.assert_equal(data_adrs, bz_grid_address)
             np.testing.assert_equal(data_map, bz_map)
 
     def test_get_grid_points_and_bz_grid_points_by_rotations(self):
+        # fmt: off
         data = [[21, 55, 31, 61, 61, 21, 55, 31, 21, 55, 31, 61,
                  61, 21, 55, 31, 21, 55, 31, 61, 61, 21, 55, 31,
                  21, 55, 31, 61, 61, 21, 55, 31, 21, 55, 31, 61,
@@ -746,7 +774,6 @@ class TestReciprocalMesh(unittest.TestCase):
                  6, 9, 13, 3, 18, 1, 2, 26, 6, 9, 26, 6, 9, 2, 1,
                  13, 3, 18, 26, 6, 9, 2, 1, 13, 3, 18, 26, 6, 9,
                  2, 1, 13, 3, 18]]
-
         data_bz = [[21, 55, 31, 61, 61, 21, 55, 31, 21, 55, 31, 61,
                     61, 21, 55, 31, 21, 55, 31, 61, 61, 21, 55, 31,
                     21, 55, 31, 61, 61, 21, 55, 31, 21, 55, 31, 61,
@@ -756,16 +783,16 @@ class TestReciprocalMesh(unittest.TestCase):
                     6, 9, 13, 3, 18, 1, 2, 26, 6, 9, 26, 6, 9, 2, 1,
                     13, 3, 18, 26, 6, 9, 2, 1, 13, 3, 18, 26, 6, 9,
                     2, 1, 13, 3, 18]]
+        # fmt: on
 
         for i, (cell, mesh, grid_address, rotations) in enumerate(
-                zip(self.cells, self.meshes, self.grid_addresses,
-                    self.rotations)):
+            zip(self.cells, self.meshes, self.grid_addresses, self.rotations)
+        ):
             rec_rots = [r.T for r in rotations]
 
-            gps = get_grid_points_by_rotations([1, 1, 1],
-                                               rec_rots,
-                                               mesh,
-                                               is_dense=False)
+            gps = get_grid_points_by_rotations(
+                [1, 1, 1], rec_rots, mesh, is_dense=False
+            )
 
             # The order of numbers of data[i] can change when the order
             # of rotations changes. But frequencies should not change.
@@ -778,38 +805,31 @@ class TestReciprocalMesh(unittest.TestCase):
             # print(", ".join(["%d" % g for g in gps]))
 
             np.testing.assert_equal(data[i], gps)
-            gps = get_grid_points_by_rotations([1, 1, 1],
-                                               rec_rots,
-                                               mesh,
-                                               is_dense=True)
+            gps = get_grid_points_by_rotations([1, 1, 1], rec_rots, mesh, is_dense=True)
             np.testing.assert_equal(data[i], gps)
 
             bz_grid_address, bz_map = relocate_BZ_grid_address(
-                grid_address,
-                mesh,
-                np.linalg.inv(cell[0]))
-            bz_gps = get_BZ_grid_points_by_rotations([1, 1, 1],
-                                                     rec_rots,
-                                                     mesh,
-                                                     bz_map,
-                                                     is_dense=False)
+                grid_address, mesh, np.linalg.inv(cell[0])
+            )
+            bz_gps = get_BZ_grid_points_by_rotations(
+                [1, 1, 1], rec_rots, mesh, bz_map, is_dense=False
+            )
 
             # print(i)
             # print(", ".join(["%d" % g for g in bz_gps]))
 
             np.testing.assert_equal(data_bz[i], bz_gps)
-            diff_address = bz_grid_address[:len(grid_address)] - grid_address
+            diff_address = bz_grid_address[: len(grid_address)] - grid_address
             np.testing.assert_equal(diff_address % mesh, 0)
 
-            bz_gps = get_BZ_grid_points_by_rotations([1, 1, 1],
-                                                     rec_rots,
-                                                     mesh,
-                                                     bz_map,
-                                                     is_dense=True)
+            bz_gps = get_BZ_grid_points_by_rotations(
+                [1, 1, 1], rec_rots, mesh, bz_map, is_dense=True
+            )
             np.testing.assert_equal(data_bz[i], bz_gps)
 
     def test_get_grid_point_from_address(self):
         mesh = (5, 5, 5)
+        # fmt: off
         adrs_ref = [0, 25, 50, 75, 100, 5, 30, 55, 80, 105, 10, 35, 60, 85,
                     110, 15, 40, 65, 90, 115, 20, 45, 70, 95, 120, 1, 26, 51,
                     76, 101, 6, 31, 56, 81, 106, 11, 36, 61, 86, 111, 16, 41,
@@ -819,12 +839,15 @@ class TestReciprocalMesh(unittest.TestCase):
                     108, 13, 38, 63, 88, 113, 18, 43, 68, 93, 118, 23, 48, 73,
                     98, 123, 4, 29, 54, 79, 104, 9, 34, 59, 84, 109, 14, 39,
                     64, 89, 114, 19, 44, 69, 94, 119, 24, 49, 74, 99, 124]
-        adrs = [get_grid_point_from_address([i, j, k], mesh)
-                for i, j, k in list(np.ndindex(mesh))]
+        # fmt: on
+        adrs = [
+            get_grid_point_from_address([i, j, k], mesh)
+            for i, j, k in list(np.ndindex(mesh))
+        ]
         np.testing.assert_equal(adrs_ref, adrs)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     suite = unittest.TestLoader().loadTestsFromTestCase(TestReciprocalMesh)
     unittest.TextTestRunner(verbosity=2).run(suite)
     # unittest.main()
