@@ -78,8 +78,7 @@ int kgd_get_grid_point_double_mesh(const int address_double[3],
 size_t kgd_get_dense_grid_point_double_mesh(const int address_double[3],
                                             const int mesh[3]);
 void kgd_get_grid_address_double_mesh(int address_double[3],
-                                      const int address[3],
-                                      const int mesh[3],
+                                      const int address[3], const int mesh[3],
                                       const int is_shift[3]);
 
 #endif
