@@ -40,22 +40,28 @@
 #include "symmetry.h"
 
 typedef struct {
-  Cell *bravais;
-  Symmetry *symmetry;
-  int *wyckoffs;
-  char (*site_symmetry_symbols)[7];
-  int *equivalent_atoms;
-  int *crystallographic_orbits;
-  int *std_mapping_to_primitive;
-  double rotation[3][3];
+    Cell *bravais;
+    Symmetry *symmetry;
+    int *wyckoffs;
+    char (*site_symmetry_symbols)[7];
+    int *equivalent_atoms;
+    int *crystallographic_orbits;
+    int *std_mapping_to_primitive;
+    double rotation[3][3];
 } ExactStructure;
 
-ExactStructure *
-ref_get_exact_structure_and_symmetry(Spacegroup * spacegroup,
-                                     const Cell * primitive,
-                                     const Cell * cell,
-                                     const int * mapping_table,
-                                     const double symprec);
+ExactStructure *ref_get_exact_structure_and_symmetry(Spacegroup *spacegroup,
+                                                     const Cell *primitive,
+                                                     const Cell *cell,
+                                                     const int *mapping_table,
+                                                     const double symprec);
 void ref_free_exact_structure(ExactStructure *exstr);
+int ref_find_similar_bravais_lattice(Spacegroup *spacegroup,
+                                     const double symprec);
+void ref_get_conventional_lattice(double lattice[3][3],
+                                  SPGCONST Spacegroup *spacegroup);
+void ref_measure_rigid_rotation(double rotation[3][3],
+                                SPGCONST double bravais_lattice[3][3],
+                                SPGCONST double std_lattice[3][3]);
 
 #endif
