@@ -41,44 +41,44 @@
 #include "symmetry.h"
 
 typedef struct {
-  int number;
-  int hall_number;
-  int pointgroup_number;
-  char schoenflies[7];
-  char hall_symbol[17];
-  char international[32];
-  char international_long[20];
-  char international_short[11];
-  char choice[6];
-  double bravais_lattice[3][3];
-  double origin_shift[3];
+    int number;
+    int hall_number;
+    int pointgroup_number;
+    char schoenflies[7];
+    char hall_symbol[17];
+    char international[32];
+    char international_long[20];
+    char international_short[11];
+    char choice[6];
+    double bravais_lattice[3][3];
+    double origin_shift[3];
 } Spacegroup;
 
 typedef enum {
-  CENTERING_ERROR,
-  PRIMITIVE,
-  BODY,
-  FACE,
-  A_FACE,
-  B_FACE,
-  C_FACE,
-  BASE,
-  R_CENTER,
+    CENTERING_ERROR,
+    PRIMITIVE,
+    BODY,
+    FACE,
+    A_FACE,
+    B_FACE,
+    C_FACE,
+    BASE,
+    R_CENTER,
 } Centering;
 
-Spacegroup * spa_search_spacegroup(const Primitive * primitive,
-                                   const int hall_number,
-                                   const double symprec,
-                                   const double angle_tolerance);
-int spa_search_spacegroup_with_symmetry(const Symmetry *symmetry,
-                                        const double symprec);
-Cell * spa_transform_to_primitive(int * mapping_table,
-                                  const Cell * cell,
-                                  SPGCONST double trans_mat[3][3],
-                                  const Centering centering,
-                                  const double symprec);
-Cell * spa_transform_from_primitive(const Cell * primitive,
-                                    const Centering centering,
-                                    const double symprec);
+Spacegroup *spa_search_spacegroup(const Primitive *primitive,
+                                  const int hall_number, const double symprec,
+                                  const double angle_tolerance);
+Spacegroup *spa_search_spacegroup_with_symmetry(const Symmetry *symmetry,
+                                                SPGCONST double prim_lat[3][3],
+                                                const double symprec);
+Cell *spa_transform_to_primitive(int *mapping_table, const Cell *cell,
+                                 SPGCONST double trans_mat[3][3],
+                                 const Centering centering,
+                                 const double symprec);
+Cell *spa_transform_from_primitive(const Cell *primitive,
+                                   const Centering centering,
+                                   const double symprec);
+void spa_copy_spacegroup(Spacegroup *dst, SPGCONST Spacegroup *src);
 
 #endif
